globals [
  fast average slow losses  ;; current counts
  avg-speed                 ;; current averages
  clock vsplit vclock       ;; clock variables
  fade-needed?
]

turtles-own [
  speed mass energy                     ;; turtle info
  v1t v1l tmp-turtle                    ;; collision info (turtle 1)
  heading2 mass2 speed2 v2t v2l turtle2 ;; collision info (turtle 2)
  theta                                 ;; collision info (both turtles)
]

to setup
  ca
  make-box
  set fade-needed? false
  set clock 0
  set vclock 0
  cct number [
    set speed initspeed
    set mass initmass
    if who != 0
      [ random-position ]
    rt random 360
    set shape "circle"
    recolor
  ]
  update-variables
  setup-plots
  setup-histograms
  do-plotting
  do-histograms
end

to update-variables
  ask turtles
    [ set energy (0.5 * speed * speed * mass) ]
  set average count turtles with [color = green]
  set slow    count turtles with [color = blue]
  set fast    count turtles with [color = red]
  set losses  number - count turtles
  set avg-speed mean values-from turtles [speed]
  set vsplit ceiling max values-from turtles [speed + gravity]
end

to factor-gravity  ;; turtle procedure
  locals [vx vy]
  set vx (sin heading * speed)
  set vy (cos heading * speed) - gravity / vsplit
  set speed sqrt ((vy * vy) + (vx * vx))
  recolor
  set heading atan vx vy
end

to go
  ask turtles [ bounce ]
  ask turtles [ move ]
  if not any turtles [ stop ]
  if trace?
    [ ask min-one-of turtles [ who ]
        [ stamp gray
          set fade-needed? true ] ]
  set vclock (vclock + 1)
  if (vclock = vsplit)
  [ set clock (clock + 1)
    set vclock 0
    update-variables
    do-plotting
    do-histograms
    if fade-needed? [ fade-patches ]
  ]
end

to bounce  ;; turtle procedure
  locals [new-px new-py]
  ; if we're not about to hit the ground (yellow patch),
  ; we don't need to do any further checks
  if pcolor-of patch-at dx dy != yellow [ stop ]
  ; get the coordinates of the patch we'll be on if we go forward 1
  set new-px round (xcor + dx)
  set new-py round (ycor + dy)
  ; if hitting ground, reflect heading around y axis
  set heading (180 - heading)
end

to move  ;; turtle procedure
  ;; In other GasLab models, we use "jump speed / vsplit" to move the
  ;; turtle the right distance along its current heading.  In this
  ;; model, though, the molecules are affected by gravity as well, so we
  ;; need to offset the turtle vertically by an additional amount.  The
  ;; easiest way to do this is to use "setxy" instead of "jump".
  ;; Trigonometry tells us that "jump speed / vsplit" is equivalent to:
  ;;   setxy (xcor + sin heading * speed / vsplit)
  ;;         (ycor + cos heading * speed / vsplit)
  ;; so to take gravity into account we just need to alter ycor
  ;; by an additional amount given by the classical physics equation:
  ;;   y(t) = 0.5*a*t^2 + v*t + y(t-1)
  ;; but taking vsplit into account, since vsplit is a subdivider of t.
  setxy (xcor + sin heading * speed / vsplit)
        (ycor + cos heading * speed / vsplit - gravity / (2 * vsplit * vsplit))
  factor-gravity
  if (pycor = screen-edge-y) [ die ]
  check-for-collision
end

to check-for-collision  ;; turtle procedure
  if count other-turtles-here = 1
    [ set tmp-turtle random-one-of other-turtles-here
      if ((who > who-of tmp-turtle) and (turtle2 != tmp-turtle))
        [ collide ]
    ]
end

to collide  ;; turtle procedure
  get-turtle2-info
  calculate-velocity-components
  set-new-speed-and-headings
end

to get-turtle2-info  ;; turtle procedure
  set turtle2 tmp-turtle
  set mass2 mass-of turtle2
  set speed2 speed-of turtle2
  set heading2 heading-of turtle2
end

to calculate-velocity-components
  locals [vcm]  ;; CM vel. along dir. theta
  set theta (random 360)
  set v1l (speed * sin (theta - heading))
  set v1t (speed * cos (theta - heading))
  set v2l (speed2 * sin (theta - heading2))
  set v2t (speed2 * cos (theta - heading2))
  set vcm (((mass * v1t) + (mass2 * v2t)) / (mass + mass2))
  set v1t (vcm + vcm - v1t)
  set v2t (vcm + vcm - v2t)
end

to set-new-speed-and-headings  ;; turtle procedure
  set speed sqrt ((v1t * v1t) + (v1l * v1l))
  set heading (theta - (atan v1l v1t)) 

  set speed-of turtle2 sqrt ((v2t * v2t) + (v2l * v2l))
  set heading-of turtle2 (theta - (atan v2l v2t))

  recolor
  ask turtle2 [ recolor ]
end

to recolor  ;; turtle procedure
  ifelse speed < (0.5 * initspeed)
    [ set color blue ]
    [ ifelse speed > (1.5 * initspeed)
        [ set color red ]
        [ set color green ] ]
end

to fade-patches
  locals [trace-patches]
  set trace-patches patches with [(pcolor != yellow) and (pcolor != black)]
  ifelse any trace-patches
    [ ask trace-patches
      [ set pcolor ( pcolor - 0.4 )
        if (not trace?) or (round pcolor = black)
          [ set pcolor black ] ] ]
    [ set fade-needed? false ]
end

to make-box
  ask patches with [pycor = (0 - screen-edge-y)]
    [ set pcolor yellow ]
end

to random-position  ;; turtle procedure
  setxy (random screen-size-x) (0 - random (screen-edge-y - 1))
end

;;; plotting procedures
to setup-plots
  set-current-plot "Speed Counts"
  set-plot-y-range 0 number

  set-current-plot "Height vs. Energy"
  set-plot-x-range 0 (screen-edge-y * 2)
end

to do-plotting
  set-current-plot "Speed Counts"
  set-current-plot-pen "fast"
  plot fast
  set-current-plot-pen "average"
  plot average
  set-current-plot-pen "slow"
  plot slow

  set-current-plot "Height vs. Energy"
  plot-pen-reset
  draw-graph
end

to setup-histograms
  set-current-plot "Speed Histogram"
  set-plot-x-range 0 (initspeed * 3)
  set-plot-y-range 0 ceiling (number / 10)
  set-current-plot-pen "average"
  set-histogram-num-bars 45
  set-current-plot-pen "slow"
  set-histogram-num-bars 45
  set-current-plot-pen "fast"
  set-histogram-num-bars 45
  set-current-plot-pen "init-avg-speed"
  draw-vert-line initspeed

  set-current-plot "Energy Histogram"
  set-plot-x-range 0 (0.5 * (initspeed * 3) * (initspeed * 3) * initmass)
  set-plot-y-range 0 ceiling (number / 10)
  set-current-plot-pen "average"
  set-histogram-num-bars 45
  set-current-plot-pen "slow"
  set-histogram-num-bars 45
  set-current-plot-pen "fast"
  set-histogram-num-bars 45

  set-current-plot "Density Histogram"
  set-plot-x-range 0 (screen-edge-y * 2)
  set-plot-y-range 0 (screen-edge-x * 2)
  set-histogram-num-bars round (screen-edge-x / 2)
end

to do-histograms
  set-current-plot "Speed Histogram"
  set-current-plot-pen "average"
  histogram turtles with [color = green] [speed]
  set-current-plot-pen "slow"
  histogram turtles with [color = blue] [speed]
  set-current-plot-pen "fast"
  histogram turtles with [color = red] [speed]
  set-current-plot-pen "average-speed"
  plot-pen-reset
  draw-vert-line avg-speed

  set-current-plot "Energy Histogram"
  set-current-plot-pen "average"
  histogram turtles with [color = green] [energy]
  set-current-plot-pen "slow"
  histogram turtles with [color = blue] [energy]
  set-current-plot-pen "fast"
  histogram turtles with [color = red] [energy]

  set-current-plot "Density Histogram"
  histogram turtles [ycor + screen-edge-y]
end

to draw-graph
  locals [n x]
  set n (0 - screen-edge-y)
  repeat (screen-edge-y / 2)
  [ set x turtles with [ (pycor >= n) and (pycor < (n + 4)) ]
    ifelse count x = 0
     [ plot 0 ]
     [ plot mean values-from x [energy] ]
    set n n + 4
  ]
end

; draws a vertical line at xval on the current-plot with the current plot-pen
to draw-vert-line [xval]
  plotxy xval plot-y-min
  plot-pen-down
  plotxy xval plot-y-max
  plot-pen-up
end


; *** NetLogo Model Copyright Notice ***
;
; This model was created as part of the project: CONNECTED MATHEMATICS:
; MAKING SENSE OF COMPLEX PHENOMENA THROUGH BUILDING OBJECT-BASED PARALLEL
; MODELS (OBPML).  The project gratefully acknowledges the support of the
; National Science Foundation (Applications of Advanced Technologies
; Program) -- grant numbers RED #9552950 and REC #9632612.
;
; Copyright 1998 by Uri Wilensky. All rights reserved.
;
; Permission to use, modify or redistribute this model is hereby granted,
; provided that both of the following requirements are followed:
; a) this copyright notice is included.
; b) this model will not be redistributed for profit without permission
;    from Uri Wilensky.
; Contact Uri Wilensky for appropriate licenses for redistribution for
; profit.
;
; This model was converted to NetLogo as part of the project:
; PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN
; CLASSROOMS.  The project gratefully acknowledges the support of the
; National Science Foundation (REPP program) -- grant number REC #9814682.
; Converted from StarLogoT to NetLogo, 2001.  Updated 2002.
;
; To refer to this model in academic publications, please use:
; Wilensky, U. (1998).  NetLogo GasLab Atmosphere model.
; http://ccl.northwestern.edu/netlogo/models/GasLabAtmosphere.
; Center for Connected Learning and Computer-Based Modeling,
; Northwestern University, Evanston, IL.
;
; *** End of NetLogo Model Copyright Notice ***
@#$#@#$#@
GRAPHICS-WINDOW
285
10
607
332
80
80
2.0
0
10
0
0

CC-WINDOW
98
197
276
332
Command Center

MONITOR
9
283
89
332
clock
clock
0
1

MONITOR
9
197
89
246
 avg-speed
avg-speed
2
1

MONITOR
78
139
138
188
average
average
0
1

MONITOR
9
139
69
188
fast
fast
0
1

MONITOR
147
139
207
188
slow
slow
0
1

SWITCH
147
10
276
43
trace?
trace?
0
1
-1000

SLIDER
147
96
276
129
initmass
initmass
1.0
20.0
5.0
1.0
1
NIL

SLIDER
147
53
276
86
number
number
1
500
400
1
1
NIL

SLIDER
9
96
138
129
initspeed
initspeed
1.0
20.0
5.0
1.0
1
NIL

BUTTON
78
10
138
43
go
go
T
1
T
OBSERVER

BUTTON
9
10
69
43
NIL
setup
NIL
1
T
OBSERVER

PLOT
9
343
216
513
Speed Counts
time
count
0.0
20.0
0.0
400.0
true
false
PENS
"fast" 1.0 0 -65536 true
"average" 1.0 0 -11352576 true
"slow" 1.0 0 -16776961 true

PLOT
225
343
475
513
Speed Histogram
speed
count
0.0
15.0
0.0
40.0
false
false
PENS
"fast" 1.0 1 -65536 true
"average" 1.0 1 -11352576 true
"slow" 1.0 1 -16776961 true
"average-speed" 1.0 0 -7566196 true
"init-avg-speed" 1.0 0 -16777216 true

PLOT
484
343
734
513
Energy Histogram
energy
count
0.0
450.0
0.0
40.0
false
false
PENS
"fast" 1.0 1 -65536 true
"average" 1.0 1 -11352576 true
"slow" 1.0 1 -16776961 true

SLIDER
9
53
138
86
gravity
gravity
0.0
5.0
1.0
0.1
1
NIL

MONITOR
216
139
276
188
NIL
losses
0
1

PLOT
616
10
813
166
Height vs. Energy
height
energy
0.0
160.0
0.0
500.0
false
false
PENS
"default" 4.0 1 -11352576 true

PLOT
616
176
813
332
Density Histogram
height
count
0.0
160.0
0.0
160.0
false
false
PENS
"default" 1.0 1 -11352576 true

@#$#@#$#@
WHAT IS IT?
-----------
This model is part of the GasLab collection of models.  See GasLab Gas in a Box for an introduction to the GasLab collection.

This model simulates the effect of a gravity on gas molecules.


HOW IT WORKS
------------
For the basics of how all GasLab models work, see GasLab Gas in a Box.

In this model, a gaseous "atmosphere" is placed above the surface of a "planet", represented by a yellow line at the bottom of the screen.  Every molecule is given additional velocity downward during each tick, as it would get in a gravitational field. The molecules bounce off the "ground". They disappear if they reach the top of the screen, as if they had escaped the planet's gravitational field.


HOW TO USE IT
-------------
Initial settings:
- GRAVITY: strength of the gravitational acceleration
- NUMBER: number of gas molecules
- INITSPEED: initial speed of each molecule
- INITMASS: mass of each molecule

The SETUP button will set the initial conditions.  The GO button will run the simulation.

Other settings:
- TRACE?: Traces the path of one of the molecules.  This path fades over time to make the screen less cluttered.

Monitors:
- FAST, AVERAGE, SLOW: numbers of molecules with different speeds: fast (red), average (green), and slow (blue).
- LOSSES: number of molecules that have disappeared at the top edge of the screen.
- AVG-SPEED: average speed of the molecules.
- CLOCK: number of ticks that have run.

Plots:
- SPEED COUNTS: plots the number of molecules in each range of speed.
- SPEED HISTOGRAM: speed distribution of all the molecules.  The gray line is the average value, and the black line is the initial average.
- ENERGY HISTOGRAM: distribution of energies of all the molecules, calculated as m*v*v/2.
- HEIGHT VS. ENERGY: shows the mean energy of the molecules at each 'layer' of the atmosphere.
- DENSITY HISTOGRAM: shows the number of molecules at each 'layer' of the atmosphere, i.e. its local density.


THINGS TO NOTICE
----------------
Try to predict what the screen will look like after a while, and why.

Watch the gray path of one molecule. What can you say about its motion?

Watch the change in density distribution as the model runs.

As the model runs, what happens to the average speed and kinetic energy of the molecules?  If they gain energy, where does it come from?   What happens to the speed and energy distributions?


THINGS TO TRY
-------------
What happens when gravity is increased or decreased?

Change the initial number, speed and mass.  What happens to the density distribution?

What factors affect how many molecules escape this planet?

Does this model come to some sort of equilibrium?  How can you tell when it has been reached?

Try and find out if the distribution of the molecules in this model is the same as what is predicted by conventional physical laws.

Try making gravity negative.


EXTENDING THE MODEL
-------------------
Find a way to plot the relative "temperature" of the gas as a function of distance from the planet.

Try this model with molecules of different masses.  You could color each mass differently to be able to see where they go.  Are their distributions different?  Which ones escape most easily?  What does this suggest about the composition of an atmosphere?

The fact that molecules escape when they reach a certain height isn't completely realistic, especially in the case when the molecule was about to turn back towards the planet.  Improve the model by allowing molecules that have "escaped" to re-enter the atmosphere once gravity pulls them back down.  How does this change the behavior of the model?  Keeping track of actual losses (molecules which reached the escape velocity of the planet) would be interesting.  Under what conditions will molecules reach escape velocity at all?

Make the "planet" into a central point instead of a flat plane.

This basic model could be used to explore other situations where freely moving molecules have forces on them -- e.g. a centrifuge or charged particles (ions) in an electrical field.


NETLOGO FEATURES
----------------
Because of the influence of gravity, the molecules follow curved paths.  Since NetLogo models time in discrete steps, these curved paths must be approximated with a series of short straight lines.  This is the source of a slight inaccuracy where the molecules gradually lose energy if the model runs for a long time.  (The effect is as though the collisions with the ground were slightly inelastic.)  The inaccuracy can be reduced by increasing vsplit, but the model will run slower. 


RELATED MODELS
---------------
This model is part of the GasLab suite and curriculum.
See, in particular, Gas in a Box and Gravity Box, which is a modified version of atmosphere with a ceiling on the atmosphere.


CREDITS AND REFERENCES
----------------------
To refer to this model in academic publications, please use: Wilensky, U. (1998).  NetLogo GasLab Atmosphere model. http://ccl.northwestern.edu/netlogo/models/GasLabAtmosphere. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.
@#$#@#$#@
default
true
0
Polygon -7566196 true true 150 5 40 250 150 205 260 250

circle
false
0
Circle -7566196 true true 35 35 230

@#$#@#$#@
NetLogo 1.2beta2
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
